==> SnappEmailApiClient-0.3.11b0.zip: SnappEmailApiClient-0.3.11b0/snapp_email/endpoints/stream/StreamName_22Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import StreamName_22
from snapp_email.datacontract.utils import export_dict, fill


class StreamName_22Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, accept_type=None):
        """
        Retrieve options available for resource 'StreamName_22'.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: StreamName_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'stream'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.stream.name-5.18+json',
            'Accept': 'application/vnd.4thoffice.stream.name-5.18+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers)
        
        return fill(StreamName_22, response.json())
    
    def get(self, streamId, accept_type=None):
        """
        Get stream name.
        
        :param streamId: 
        :type streamId: 
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: StreamName_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
            'streamId': streamId,
        }
        endpoint = 'stream/{streamId}'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.stream.name-5.18+json',
            'Accept': 'application/vnd.4thoffice.stream.name-5.18+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('get', endpoint, url_parameters, add_headers)
        
        return fill(StreamName_22, response.json())
    
    def update(self, obj, streamId, accept_type=None):
        """
        Update stream name.
        
        :param obj: Object to be persisted
        :type obj: StreamName_22
        
        :param streamId: 
        :type streamId: 
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: StreamName_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
            'streamId': streamId,
        }
        endpoint = 'stream/{streamId}'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.stream.name-5.18+json',
            'Accept': 'application/vnd.4thoffice.stream.name-5.18+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('put', endpoint, url_parameters, add_headers, data=json.dumps(data))
        
        return fill(StreamName_22, response.json())

==> SnappEmailApiClient-0.3.19.zip: SnappEmailApiClient-0.3.19/snapp_email/endpoints/stream/StreamName_22Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import StreamName_22
from snapp_email.datacontract.utils import export_dict, fill


class StreamName_22Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'StreamName_22'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: StreamName_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'stream'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.stream.name-5.18+json',
            'Accept': 'application/vnd.4thoffice.stream.name-5.18+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(StreamName_22, response.json(), content_type=response.headers['Content-Type'])
    
    def get(self, streamId, impersonate_user_id=None, accept_type=None):
        """
        Get stream name.
        
        :param streamId: 
        :type streamId: 
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: StreamName_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
            'streamId': streamId,
        }
        endpoint = 'stream/{streamId}'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.stream.name-5.18+json',
            'Accept': 'application/vnd.4thoffice.stream.name-5.18+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('get', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(StreamName_22, response.json(), content_type=response.headers['Content-Type'])
    
    def update(self, obj, streamId, impersonate_user_id=None, accept_type=None):
        """
        Update stream name.
        
        :param obj: Object to be persisted
        :type obj: StreamName_22
        
        :param streamId: 
        :type streamId: 
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: StreamName_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
            'streamId': streamId,
        }
        endpoint = 'stream/{streamId}'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.stream.name-5.18+json',
            'Accept': 'application/vnd.4thoffice.stream.name-5.18+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('put', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id, data=json.dumps(data))
        
        return fill(StreamName_22, response.json(), content_type=response.headers['Content-Type'])
